Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(755)

Unified Diff: sdk/lib/io/http_utils.dart

Issue 14660009: Implement support for application/x-www-form-urlencoded' form data in HttpBodyHandler. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Cleanup Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sdk/lib/io/http_multipart_form_data_impl.dart ('k') | tests/standalone/io/http_body_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/io/http_utils.dart
diff --git a/sdk/lib/io/http_utils.dart b/sdk/lib/io/http_utils.dart
index 3a72c6149b63469ad653e161b64b590d138c5f5b..8e957bf7f2a0bc580c91d18b660efc82f0c5f3a8 100644
--- a/sdk/lib/io/http_utils.dart
+++ b/sdk/lib/io/http_utils.dart
@@ -359,9 +359,9 @@ class _HttpUtils {
return new DateTime.utc(year, month, dayOfMonth, hour, minute, second, 0);
}
// Parse a string with HTTP entities. Returns null if the string ends in the
// middle of a http entity.
- static String parseHttpEntityString(String input) {
+ static String decodeHttpEntityString(String input) {
int amp = input.lastIndexOf('&');
if (amp < 0) return input;
int end = input.lastIndexOf(';');
@@ -359,9 +359,9 @@ class _HttpUtils {
return new DateTime.utc(year, month, dayOfMonth, hour, minute, second, 0);
}
- // Parse a string with HTTP entities. Returns null if the string ends in the
+ // Decode a string with HTTP entities. Returns null if the string ends in the
// middle of a http entity.
« no previous file with comments | « sdk/lib/io/http_multipart_form_data_impl.dart ('k') | tests/standalone/io/http_body_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698